@@ -6,6 +6,7 @@ from codepack.plugins.callback import Callback
 from collections.abc import Iterable, Callable
 from functools import partial
 from typing import Any, TypeVar, Union, Optional
+from queue import Queue
 
 
 CodeSnapshot = TypeVar('CodeSnapshot', bound='codepack.plugins.snapshots.code_snapshot.CodeSnapshot')
@@ -97,7 +98,7 @@ class Code(CodeBase):
                 for c in callback:
                     self.register_callback(callback=c)
             else:
-                raise TypeError(type(name))
+                raise TypeError(type(name))  # pragma: no cover
         elif isinstance(callback, Callable):
             if isinstance(name, list):
                 _name = name[0]
@@ -111,12 +112,12 @@ class Code(CodeBase):
                 else:
                     _name = callback.__name__
             else:
-                raise TypeError(type(name))
+                raise TypeError(type(name))  # pragma: no cover
             self.callbacks[_name] = callback
         elif callback is None:
             pass
         else:
-            raise TypeError(type(callback))
+            raise TypeError(type(callback))  # pragma: no cover
 
     def run_callback(self, state: Optional[Union[State, str]] = None, message: Optional[str] = None) -> None:
         for callback in self.callbacks.values():
@@ -141,7 +142,22 @@ class Code(CodeBase):
             raise AssertionError("either 'function' or 'source' should not be None")
         self.description = self.function.__doc__.strip() if self.function.__doc__ is not None else str()
 
+    def _collect_linked_ids(self) -> set:
+        ids = set()
+        q = Queue()
+        q.put(self)
+        while not q.empty():
+            code = q.get()
+            ids.add(code.id)
+            for c in {**code.children, **code.parents}.values():
+                if c.id not in ids:
+                    q.put(c)
+        return ids
+
     def link(self, other: 'Code') -> None:
+        linked_ids = self._collect_linked_ids()
+        if other.id in linked_ids:
+            raise ValueError("'%s' is already linked" % other.id)
         self.children[other.id] = other
         other.parents[self.id] = self
         if self.serial_number not in other.dependency:
@@ -256,6 +272,19 @@ class Code(CodeBase):
     def save(self, update: bool = False) -> None:
         self.service['storage'].save(item=self, update=update)
 
+    @classmethod
+    def load(cls, id: Union[str, list], storage_service: Optional[StorageService] = None)\
+            -> Optional[Union['Code', list]]:
+        if storage_service is None:
+            storage_service = Default.get_service('code', 'storage_service')
+        return storage_service.load(id)
+
+    @classmethod
+    def remove(cls, id: Union[str, list], storage_service: Optional[StorageService] = None) -> None:
+        if storage_service is None:
+            storage_service = Default.get_service('code', 'storage_service')
+        storage_service.remove(id=id)
+
     def receive(self, arg: str) -> Dependency:
         self.assert_arg(arg)
         return Dependency(code=self, arg=arg)
